Versions
========

0.0.8 (16.04.2020)
========
- Upgrade 'enforce-pep8' package
- Ignore 'I100' flake8 rule
- Describe additional meta data for packaging
- Conform python class naming with forward dunder

0.0.7 (14.04.2020)
========
- Include Procfile into packaging

0.0.6 (14.04.2020)
========
- Save current installed python dependencies
- Add PYPI badges

0.0.5 (10.04.2020)
========
- Enhance pypan tool help
- Introduce extra packaging files
- Add pretty python interpreters to dev requirements
- Support 'pytest-mock' plugin
- Upgrade 'enforce-pep8' package

0.0.4 (06.04.2020)
========
- Use 100 lines of code
- Support 'back to top' readme navigation

0.0.3 (05.04.2020)
========
- Specify local debug section

0.0.2 (05.04.2020)
========
- Describe demo usage

0.0.1 (05.04.2020)
========
- Support colored user prompt
- Build project environment setup
- Include runtime.txt template file
- Fix code analyser linters
- Show tool usage
- Add 'disallow_subclassing_any' argument to mypy tool
- Introduce template folder
- Introduce package template metafiles
- Define 'pypans' package name
- Introduce initial version of a project